===============
Utility Scripts
===============

.. click:: ravenpy.cli:generate_grid_weights
   :prog: ravenpy generate-grid-weights
   :nested: full

.. click:: ravenpy.cli:aggregate_forcings_to_hrus
   :prog: ravenpy aggregate-forcings-to-hrus
   :nested: full
